# NP.Grpc.PythonRelayInterfaces

This package can be used to provide Python language broadcasting and observing interfaces for the RelayServer described in 
my https://www.codeproject.com/Articles/5353258/Publish-Subscribe-gRPC-Relay-Server-with-Separatio article
